# pylst

# Shields for version badges
[![PyPI Version](https://img.shields.io/pypi/v/pylst.svg)](https://pypi.python.org/pypi/pylst)

**pylst is a Python package designed for processing and visualizing Landsat Land Surface Temperature (LST) data.**

- Free software: MIT license
- Documentation: [pylst Documentation](https://Azad77.github.io/pylst)

## Features

- Comprehensive processing tools for Landsat LST data.
- Flexible visualization methods for analyzing temperature data.
- Easy-to-use functions to compute and manipulate temperature-related indices.

## Getting Started
# Installation

To install pylst, you can use `pip`:

```bash
pip install pylst